@@ -8,11 +8,13 @@
 #' @keywords internal
 #' @noRd
 cross_by = function(data_x, data_y, funs, funs_arg, percent_pattern, total, percent_digits,
-                    showNA, label, test, times, followup, drop_levels,
+                    showNA, label, test, times, followup, drop_levels, remove_zero_percent,
                     test_args, cor_method, effect, effect_args){
   if(!is.null(data_y) && ncol(data_y)>1) cli_abort(glue("data_y has {ncol(data_y)} columns (max=1)"))
   errors = rlang::env()
 
+  if(isTRUE(drop_levels) & is.factor(data_y[[1]])) data_y[[1]] = fct_drop(data_y[[1]])
+
   by_levels = length(unique(na.omit(data_y[[1]])))
   if(!is.numeric(data_y[[1]]) && isTRUE(effect) && by_levels!=2){
     cli_warn(c("Cannot calculate crosstable effects as there is not exactly 2 groups in `by`.",
@@ -28,7 +30,8 @@ cross_by = function(data_x, data_y, funs, funs_arg, percent_pattern, total, perc
     }
 
     if(anyNA(.x) && "NA" %in% .x) {
-      .x[.x=="NA"] = "\"NA\""
+      .x = if_else(.x!="NA", .x, factor("\"NA\""))
+      if(is.factor(.x)) .x = fct_drop(.x, only="NA")
     }
     if(!is.list(.x)){ #TODO is.list pour les erreurs, mieux vaudrait une classe spéciale?
       data_x[.y] = .x
@@ -57,7 +60,7 @@ cross_by = function(data_x, data_y, funs, funs_arg, percent_pattern, total, perc
     } else if(is.character.or.factor(.x)){
       rtn=cross_categorical(data_x[.y], data_y, percent_pattern=percent_pattern,
                             showNA=showNA, total=total, label=label, percent_digits=percent_digits,
-                            drop_levels=drop_levels,
+                            drop_levels=drop_levels, remove_zero_percent=remove_zero_percent,
                             test=test, test_args=test_args, effect=effect, effect_args=effect_args)
     } else if(is.Surv(.x)){
       rtn=cross_survival(data_x[.y], data_y, times=times, followup=followup,
